diff --git a/example/SE/0_classes/Makefile b/example/SE/0_classes/Makefile
index 3e8145cd836e02b9e871bf0ebe16b6e67d963f94..172ffbd665222f8f35a17e1b68d2d628a8f07208 100644
--- a/example/SE/0_classes/Makefile
+++ b/example/SE/0_classes/Makefile
@@ -10,7 +10,7 @@ OBJ = main.o
 	$(CC) -O0 -g3 -c --std=c++11 -o $@ $< $(INCLUDE_PATH)
 
 se_classes: $(OBJ)
-	$(CC) -o $@ $^ $(CFLAGS) $(LIBS_PATH) $(LIBS_SE2)
+	$(CC) -o $@ $^ $(CFLAGS) $(LIBS_PATH) $(LIBS)
 
 all: se_classes
 
diff --git a/example/SE/1_classes/Makefile b/example/SE/1_classes/Makefile
index 3e8145cd836e02b9e871bf0ebe16b6e67d963f94..172ffbd665222f8f35a17e1b68d2d628a8f07208 100644
--- a/example/SE/1_classes/Makefile
+++ b/example/SE/1_classes/Makefile
@@ -10,7 +10,7 @@ OBJ = main.o
 	$(CC) -O0 -g3 -c --std=c++11 -o $@ $< $(INCLUDE_PATH)
 
 se_classes: $(OBJ)
-	$(CC) -o $@ $^ $(CFLAGS) $(LIBS_PATH) $(LIBS_SE2)
+	$(CC) -o $@ $^ $(CFLAGS) $(LIBS_PATH) $(LIBS)
 
 all: se_classes
 
diff --git a/example/SE/1_classes/se_classes b/example/SE/1_classes/se_classes
index 8abee31e7510a20b11c3ab45ff31f06dfeeb40c8..bdb456b10f1dc30496cf1091eedd1fb2833105f7 100755
Binary files a/example/SE/1_classes/se_classes and b/example/SE/1_classes/se_classes differ
diff --git a/example/VCluster/0_simple/vcluster b/example/VCluster/0_simple/vcluster
index 8a26962f216fd64db5e0e5d1ed83f2c405c27813..b3ad51f0032621f8737777595c733989712ca6f0 100755
Binary files a/example/VCluster/0_simple/vcluster and b/example/VCluster/0_simple/vcluster differ
diff --git a/openfpm_data b/openfpm_data
index 4415b6823c6b94331f0bab335f3efcdbfa38982d..51c621a24979b4df3851e12987a6c5a6e5485913 160000
--- a/openfpm_data
+++ b/openfpm_data
@@ -1 +1 @@
-Subproject commit 4415b6823c6b94331f0bab335f3efcdbfa38982d
+Subproject commit 51c621a24979b4df3851e12987a6c5a6e5485913
diff --git a/example/SE/0_classes/main.cpp b/example/SE/0_classes/main.cpp
index 969628f3166b8c9d0d9da562f566472a890ddd77..640c5572977977188f9064a53867a8508ae98539 100644
--- a/example/SE/0_classes/main.cpp
+++ b/example/SE/0_classes/main.cpp
@@ -40,7 +40,7 @@ int main(int argc, char* argv[])
 	// ### WIKI 3 ###
 	//
 	// Here we Initialize the library, than we create a uniform random generator between 0 and 1 to to generate particles
 	// randomly in the domain, we create a Box that define our domain
 	//
 	init_global_v_cluster(&argc,&argv);
 	Vcluster & v_cl = *global_v_cluster;
@@ -48,7 +48,9 @@ int main(int argc, char* argv[])
 	typedef Point<2,float> s;
 
 	Box<2,float> box({0.0,0.0},{1.0,1.0});
-	
+        size_t bc[2]={NON_PERIODIC,NON_PERIODIC};
+	Ghost<2,float> g(0.01);
+
 	//
 	// ### WIKI 4 ###
 	//
@@ -85,7 +87,7 @@ int main(int argc, char* argv[])
 	// decomposition
 	//
 	{
-		vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > vd(4096,box);
+		vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > vd(4096,box,bc,g);
 
 		//
 		// ### WIKI 6 ###
@@ -95,7 +97,7 @@ int main(int argc, char* argv[])
 		//
 		try
         {
-			vect_dist_key_dx vt(0,5048);
+			vect_dist_key_dx vt(5048);
 			auto it = vd.getPos<0>(vt);
         }
 		catch (size_t e)
@@ -110,8 +112,8 @@ int main(int argc, char* argv[])
 	// we create, now two of them using new
 	//
 
-	vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > * vd1 = new vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> >(4096,box);
-	vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > * vd2 = new vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> >(4096,box);
+	vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > * vd1 = new vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> >(4096,box,bc,g);
+	vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> > * vd2 = new vector_dist<2,float, Point_test<float>, CartDecomposition<2,float> >(4096,box,bc,g);
 
 	//
 	// ### WIKI 8 ###
@@ -182,7 +184,7 @@ int main(int argc, char* argv[])
 	//
 	try
     {
-		vect_dist_key_dx vt(0,0);
+		vect_dist_key_dx vt(0);
 		auto it = vd1->getPos<0>(vt);
     }
 	catch (size_t e)
@@ -40,7 +40,7 @@ int main(int argc, char* argv[])
 	//
 	// Here we Initialize the library, than we create a uniform random generator between 0 and 1 to to generate particles
-	// randomly in the domain, we create a Box that define our domain
+	// randomly in the domain, we create a Box that define our domain, boundary conditions and ghost
 	//
 	init_global_v_cluster(&argc,&argv);